@@ -131,7 +131,7 @@ public:
 
 	/// @name Detection methods
 	/// @{
-	bool canBeBool() const { return _expr->isBool() || _expr->isFloat() || _expr->isInt() || _expr->isUndefined(); }
+	bool canBeBool() const { return _expr->isBool() || _expr->isFloat() || _expr->isInt() || _expr->isString() || _expr->isUndefined(); }
 	/// @}
 
 	/// @name Builder method
@@ -187,7 +187,12 @@ public:
 
 	YaraExpressionBuilder& contains(const YaraExpressionBuilder& other);
 	YaraExpressionBuilder& matches(const YaraExpressionBuilder& other);
+	YaraExpressionBuilder& icontains(const YaraExpressionBuilder& other);
+	YaraExpressionBuilder& iendswith(const YaraExpressionBuilder& other);
 	YaraExpressionBuilder& iequals(const YaraExpressionBuilder& other);
+	YaraExpressionBuilder& istartswith(const YaraExpressionBuilder& other);
+	YaraExpressionBuilder& startswith(const YaraExpressionBuilder& other);
+	YaraExpressionBuilder& endswith(const YaraExpressionBuilder& other);
 	YaraExpressionBuilder& defined();
 	YaraExpressionBuilder& percent();
 
